@@ -4,10 +4,10 @@ import socket
 import json
 import sys
 import os
-from pylgocq import log_convert
+from . import log_convert
 from datetime import datetime
 
-version = "0.7.5"
+version = "0.8.5"
 
 
 class ViewForm(npyscreen.Form):
